@@ -257,87 +257,101 @@ Licensed under the Apache 2.0 License
         end
       end
       devices.collect do |devicename,device|
-        begin
-          device_url = URI.parse(device.url)
-          # Handle nil scheme & port
-          scheme = "#{device_url.scheme}://" if device_url.scheme
-          port = ":#{device_url.port}" if device_url.port
+        pool = Puppet::Network::HTTP::Pool.new(Puppet[:http_keepalive_timeout])
+        Puppet.override(:http_pool => pool) do
+          # TODO when we drop support for ruby < 2.5 we can remove the extra block here
+          begin
+            device_url = URI.parse(device.url)
+            # Handle nil scheme & port
+            scheme = "#{device_url.scheme}://" if device_url.scheme
+            port = ":#{device_url.port}" if device_url.port
 
-          # override local $vardir and $certname
-          Puppet[:confdir] = ::File.join(Puppet[:devicedir], device.name)
-          Puppet[:libdir] = options[:libdir] || ::File.join(Puppet[:devicedir], device.name, 'lib')
-          Puppet[:vardir] = ::File.join(Puppet[:devicedir], device.name)
-          Puppet[:certname] = device.name
+            # override local $vardir and $certname
+            Puppet[:confdir] = ::File.join(Puppet[:devicedir], device.name)
+            Puppet[:libdir] = options[:libdir] || ::File.join(Puppet[:devicedir], device.name, 'lib')
+            Puppet[:vardir] = ::File.join(Puppet[:devicedir], device.name)
+            Puppet[:certname] = device.name
+            ssl_context = nil
 
-          unless options[:resource] || options[:facts] || options[:apply] || options[:libdir]
-            Puppet::Configurer::PluginHandler.new.download_plugins(env)
-          end
-          # this init the device singleton, so that the facts terminus
-          # and the various network_device provider can use it
-          Puppet::Util::NetworkDevice.init(device)
+            # this will reload and recompute default settings and create device-specific sub vardir
+            Puppet.settings.use :main, :agent, :ssl
 
-          if options[:resource]
-            type, name = parse_args(command_line.args)
-            Puppet.info _("retrieving resource: %{resource} from %{target} at %{scheme}%{url_host}%{port}%{url_path}") % { resource: type, target: device.name, scheme: scheme, url_host: device_url.host, port: port, url_path: device_url.path }
-            resources = find_resources(type, name)
-            if options[:to_yaml]
-              text = resources.map do |resource|
-                resource.prune_parameters(:parameters_to_include => @extra_params).to_hierayaml.force_encoding(Encoding.default_external)
-              end.join("\n")
-              text.prepend("#{type.downcase}:\n")
-            else
-              text = resources.map do |resource|
-                resource.prune_parameters(:parameters_to_include => @extra_params).to_manifest.force_encoding(Encoding.default_external)
-              end.join("\n")
-            end
-            (puts text)
-            0
-          elsif options[:facts]
-            Puppet.info _("retrieving facts from %{target} at %{scheme}%{url_host}%{port}%{url_path}") % { resource: type, target: device.name, scheme: scheme, url_host: device_url.host, port: port, url_path: device_url.path }
-            remote_facts = Puppet::Node::Facts.indirection.find(name, :environment => env)
-            # Give a proper name to the facts
-            remote_facts.name = remote_facts.values['clientcert']
-            renderer = Puppet::Network::FormatHandler.format(:console)
-            puts renderer.render(remote_facts)
-            0
-          elsif options[:apply]
-            # ensure we have a cache folder structure exists for the device
-            FileUtils.mkdir_p(Puppet[:statedir]) unless File.directory?(Puppet[:statedir])
-            # avoid reporting to server
-            Puppet::Transaction::Report.indirection.terminus_class = :yaml
-            Puppet::Resource::Catalog.indirection.cache_class = nil
+            unless options[:resource] || options[:facts] || options[:apply]
+              # ask for a ssl cert if needed, but at least
+              # setup the ssl system for this device.
+              ssl_context = setup_context
 
-            require 'puppet/application/apply'
-            begin
-              Puppet[:node_terminus] = :plain
-              Puppet[:catalog_terminus] = :compiler
-              Puppet[:catalog_cache_terminus] = nil
-              Puppet[:facts_terminus] = :network_device
-              Puppet.override(:network_device => true) do
-                Puppet::Application::Apply.new(Puppet::Util::CommandLine.new('puppet', ["apply", options[:apply]])).run_command
+              unless options[:libdir]
+                Puppet.override(ssl_context: ssl_context) do
+                  Puppet::Configurer::PluginHandler.new.download_plugins(env) if Puppet::Configurer.should_pluginsync?
+                end
               end
             end
-          else
-            Puppet.info _("starting applying configuration to %{target} at %{scheme}%{url_host}%{port}%{url_path}") % { target: device.name, scheme: scheme, url_host: device_url.host, port: port, url_path: device_url.path }
-            # this will reload and recompute default settings and create the devices sub vardir
-            Puppet.settings.use :main, :agent, :ssl
-            # ask for a ssl cert if needed, but at least
-            # setup the ssl system for this device.
-            setup_host(device.name)
 
-            require 'puppet/configurer'
-            configurer = Puppet::Configurer.new
-            configurer.run(:network_device => true, :pluginsync => Puppet::Configurer.should_pluginsync? && !options[:libdir])
+            # this init the device singleton, so that the facts terminus
+            # and the various network_device provider can use it
+            Puppet::Util::NetworkDevice.init(device)
+
+            if options[:resource]
+              type, name = parse_args(command_line.args)
+              Puppet.info _("retrieving resource: %{resource} from %{target} at %{scheme}%{url_host}%{port}%{url_path}") % { resource: type, target: device.name, scheme: scheme, url_host: device_url.host, port: port, url_path: device_url.path }
+              resources = find_resources(type, name)
+              if options[:to_yaml]
+                text = resources.map do |resource|
+                  resource.prune_parameters(:parameters_to_include => @extra_params).to_hierayaml.force_encoding(Encoding.default_external)
+                end.join("\n")
+                text.prepend("#{type.downcase}:\n")
+              else
+                text = resources.map do |resource|
+                  resource.prune_parameters(:parameters_to_include => @extra_params).to_manifest.force_encoding(Encoding.default_external)
+                end.join("\n")
+              end
+              (puts text)
+              0
+            elsif options[:facts]
+              Puppet.info _("retrieving facts from %{target} at %{scheme}%{url_host}%{port}%{url_path}") % { resource: type, target: device.name, scheme: scheme, url_host: device_url.host, port: port, url_path: device_url.path }
+              remote_facts = Puppet::Node::Facts.indirection.find(name, :environment => env)
+              # Give a proper name to the facts
+              remote_facts.name = remote_facts.values['clientcert']
+              renderer = Puppet::Network::FormatHandler.format(:console)
+              puts renderer.render(remote_facts)
+              0
+            elsif options[:apply]
+              # avoid reporting to server
+              Puppet::Transaction::Report.indirection.terminus_class = :yaml
+              Puppet::Resource::Catalog.indirection.cache_class = nil
+
+              require 'puppet/application/apply'
+              begin
+                Puppet[:node_terminus] = :plain
+                Puppet[:catalog_terminus] = :compiler
+                Puppet[:catalog_cache_terminus] = nil
+                Puppet[:facts_terminus] = :network_device
+                Puppet.override(:network_device => true) do
+                  Puppet::Application::Apply.new(Puppet::Util::CommandLine.new('puppet', ["apply", options[:apply]])).run_command
+                end
+              end
+            else
+              Puppet.info _("starting applying configuration to %{target} at %{scheme}%{url_host}%{port}%{url_path}") % { target: device.name, scheme: scheme, url_host: device_url.host, port: port, url_path: device_url.path }
+
+              overrides = {}
+              overrides[:ssl_context] = ssl_context if ssl_context
+              Puppet.override(overrides) do
+                configurer = Puppet::Configurer.new
+                configurer.run(:network_device => true, :pluginsync => false)
+              end
+            end
+          rescue => detail
+            Puppet.log_exception(detail)
+            # If we rescued an error, then we return 1 as the exit code
+            1
+          ensure
+            pool.close
+            Puppet[:libdir] = libdir
+            Puppet[:vardir] = vardir
+            Puppet[:confdir] = confdir
+            Puppet[:certname] = certname
           end
-        rescue => detail
-          Puppet.log_exception(detail)
-          # If we rescued an error, then we return 1 as the exit code
-          1
-        ensure
-          Puppet[:libdir] = libdir
-          Puppet[:vardir] = vardir
-          Puppet[:confdir] = confdir
-          Puppet[:certname] = certname
         end
       end
     end
@@ -372,17 +386,20 @@ Licensed under the Apache 2.0 License
     end
   end
 
-  def setup_host(name)
+  def setup_context
     waitforcert = options[:waitforcert] || (Puppet[:onetime] ? 0 : Puppet[:waitforcert])
-    sm = Puppet::SSL::StateMachine.new(certname: name, waitforcert: waitforcert)
+    sm = Puppet::SSL::StateMachine.new(waitforcert: waitforcert)
     sm.ensure_client_certificate
   end
 
   def setup
     setup_logs
+
+    # setup global device-specific defaults; creates all necessary directories, etc
+    Puppet.settings.use :main, :agent, :device, :ssl
+
     if options[:apply] || options[:facts] || options[:resource]
       Puppet::Util::Log.newdestination(:console)
-      Puppet.settings.use :main, :agent, :ssl
     else
       args[:Server] = Puppet[:server]
       if options[:centrallogs]
@@ -392,8 +409,6 @@ Licensed under the Apache 2.0 License
         Puppet::Util::Log.newdestination(logdest)
       end
 
-      Puppet.settings.use :main, :agent, :device, :ssl
-
       Puppet::Transaction::Report.indirection.terminus_class = :rest
 
       if Puppet[:catalog_cache_terminus]
