@@ -56,29 +56,8 @@ class Puppet::Module
   end
 
   # @api private
-  def self.parse_range(range, strict)
-    @parse_range_method ||= SemanticPuppet::VersionRange.method(:parse)
-    if @parse_range_method.arity == 1
-      @semver_gem_version ||= SemanticPuppet::Version.parse(SemanticPuppet::VERSION)
-
-      # Give user a heads-up if the desired strict setting cannot be honored
-      if strict
-        if @semver_gem_version.major < 1
-          Puppet.warn_once('strict_version_ranges', 'version_range_cannot_be_strict',
-            _('VersionRanges will never be strict when using non-vendored SemanticPuppet gem, version %{version}') % { version: @semver_gem_version},
-            :default, :default, :notice)
-        end
-      else
-        if @semver_gem_version.major >= 1
-          Puppet.warn_once('strict_version_ranges', 'version_range_always_strict',
-            _('VersionRanges will always be strict when using non-vendored SemanticPuppet gem, version %{version}') % { version: @semver_gem_version},
-            :default, :default, :notice)
-        end
-      end
-      @parse_range_method.call(range)
-    else
-      @parse_range_method.call(range, strict)
-    end
+  def self.parse_range(range)
+    SemanticPuppet::VersionRange.parse(range)
   end
 
   attr_reader :name, :environment, :path, :metadata, :tasks
@@ -87,10 +66,9 @@ class Puppet::Module
   attr_accessor :dependencies, :forge_name
   attr_accessor :source, :author, :version, :license, :summary, :description, :project_page
 
-  def initialize(name, path, environment, strict_semver = true)
+  def initialize(name, path, environment)
     @name = name
     @path = path
-    @strict_semver = strict_semver
     @environment = environment
 
     assert_validity
@@ -406,7 +384,7 @@ class Puppet::Module
 
       if version_string
         begin
-          required_version_semver_range = self.class.parse_range(version_string, @strict_semver)
+          required_version_semver_range = self.class.parse_range(version_string)
           actual_version_semver = SemanticPuppet::Version.parse(dep_mod.version)
         rescue ArgumentError
           error_details[:reason] = :non_semantic_version
@@ -432,10 +410,6 @@ class Puppet::Module
     self.environment == other.environment
   end
 
-  def strict_semver?
-    @strict_semver
-  end
-
   private
 
   def wanted_manifests_from(pattern)
