@@ -34,7 +34,7 @@ module Puppet
       if matcher = full_module_name.match(FULL_MODULE_NAME_PATTERN)
         return matcher.captures
       else
-        raise ArgumentError, "Not a valid full name: #{full_module_name}"
+        raise ArgumentError, _("Not a valid full name: %{full_module_name}") % { full_module_name: full_module_name }
       end
     end
 
@@ -130,6 +130,7 @@ module Puppet
 
       # Note: environment will have expanded the path
       options[:target_dir] = face_environment.full_modulepath.first
+
     end
 
     # Given a hash of options, we should discover or create a
@@ -157,12 +158,12 @@ module Puppet
     end
 
     # Handles parsing of module dependency expressions into proper
-    # {Semantic::VersionRange}s, including reasonable error handling.
+    # {SemanticPuppet::VersionRange}s, including reasonable error handling.
     #
     # @param where [String] a description of the thing we're parsing the
     #        dependency expression for
     # @param dep [Hash] the dependency description to parse
-    # @return [Array(String, Semantic::VersionRange, String)] a tuple of the
+    # @return [Array(String, SemanticPuppet::VersionRange, String)] a tuple of the
     #         dependent module's name, the version range dependency, and the
     #         unparsed range expression.
     def self.parse_module_dependency(where, dep)
@@ -170,10 +171,10 @@ module Puppet
       range = dep['version_requirement'] || '>= 0.0.0'
 
       begin
-        parsed_range = Semantic::VersionRange.parse(range)
+        parsed_range = Module.parse_range(range)
       rescue ArgumentError => e
         Puppet.debug "Error in #{where} parsing dependency #{dep_name} (#{e.message}); using empty range."
-        parsed_range = Semantic::VersionRange::EMPTY_RANGE
+        parsed_range = SemanticPuppet::VersionRange::EMPTY_RANGE
       end
 
       [ dep_name, parsed_range, range ]
