@@ -25,7 +25,6 @@ module Puppet::ModuleTool
         @ignore_dependencies = forced? || options[:ignore_dependencies]
         @name                = name
         @install_dir         = install_dir
-        @strict_semver       = !!options[:strict_semver]
 
         Puppet::Forge::Cache.clean
 
@@ -52,6 +51,9 @@ module Puppet::ModuleTool
       end
 
       def run
+        # Disallow anything that invokes md5 to avoid un-friendly termination due to FIPS
+        raise _("Module install is prohibited in FIPS mode.") if Facter.value(:fips_enabled)
+
         name = @name.tr('/', '-')
         version = options[:version] || '>= 0.0.0'
 
@@ -60,7 +62,7 @@ module Puppet::ModuleTool
         begin
           if installed_module = installed_modules[name]
             unless forced?
-              if Puppet::Module.parse_range(version, @strict_semver).include? installed_module.version
+              if Puppet::Module.parse_range(version).include? installed_module.version
                 results[:result] = :noop
                 results[:version] = installed_module.version
                 return results
@@ -104,7 +106,7 @@ module Puppet::ModuleTool
               # locking it to upgrades within the same major version.
               installed_range = ">=#{version} #{version.major}.x"
               graph.add_constraint('installed', mod, installed_range) do |node|
-                Puppet::Module.parse_range(installed_range, @strict_semver).include? node.version
+                Puppet::Module.parse_range(installed_range).include? node.version
               end
 
               release.mod.dependencies.each do |dep|
@@ -112,7 +114,7 @@ module Puppet::ModuleTool
 
                 range = dep['version_requirement']
                 graph.add_constraint("#{mod} constraint", dep_name, range) do |node|
-                  Puppet::Module.parse_range(range, @strict_semver).include? node.version
+                  Puppet::Module.parse_range(range).include? node.version
                 end
               end
             end
@@ -186,12 +188,12 @@ module Puppet::ModuleTool
       private
 
       def module_repository
-        @repo ||= Puppet::Forge.new(Puppet[:module_repository], @strict_semver)
+        @repo ||= Puppet::Forge.new(Puppet[:module_repository])
       end
 
       def local_tarball_source
         @tarball_source ||= begin
-          Puppet::ModuleTool::LocalTarball.new(@name, @strict_semver)
+          Puppet::ModuleTool::LocalTarball.new(@name)
         rescue Puppet::Module::Error => e
           raise InvalidModuleError.new(@name, :action => @action, :error  => e)
         end
@@ -206,7 +208,7 @@ module Puppet::ModuleTool
       end
 
       def build_single_module_graph(name, version)
-        range = Puppet::Module.parse_range(version, @strict_semver)
+        range = Puppet::Module.parse_range(version)
         graph = SemanticPuppet::Dependency::Graph.new(name => range)
         releases = SemanticPuppet::Dependency.fetch_releases(name)
         releases.each { |release| release.dependencies.clear }
