@@ -85,7 +85,6 @@ class Puppet::Node::Environment
     @modulepath = modulepath
     @manifest = manifest
     @config_version = config_version
-    @modules_strict_semver = false
   end
 
   # Creates a new Puppet::Node::Environment instance, overriding any of the passed
@@ -240,22 +239,6 @@ class Puppet::Node::Environment
     Puppet.settings.value(param, self.name)
   end
 
-  # A SemanticPuppet::VersionRange version >= 1.0.0 will not include versions with pre-release
-  # identifiers unless that is explicitly declared. This may cause backward compatibility
-  # issues when resolving module dependencies and the flag is therefore set to `false` by default.
-  #
-  # @param flag [Boolean] set to true to resolve module dependencies using strict SemVer semantics
-  #
-  def modules_strict_semver=(flag)
-    @modules_strict_semver = flag
-  end
-
-  # @return [Boolean] the current value of the modules_strict_semver flag.
-  # @api public
-  def modules_strict_semver?
-    @modules_strict_semver
-  end
-
   # @api public
   # @return [Puppet::Resource::TypeCollection] The current global TypeCollection
   def known_resource_types
@@ -330,7 +313,7 @@ class Puppet::Node::Environment
 
       @modules = module_references.collect do |reference|
         begin
-          Puppet::Module.new(reference[:name], reference[:path], self, modules_strict_semver?)
+          Puppet::Module.new(reference[:name], reference[:path], self)
         rescue Puppet::Module::Error => e
           Puppet.log_exception(e)
           nil
@@ -372,7 +355,7 @@ class Puppet::Node::Environment
             Puppet::Module.is_module_directory?(name, path)
           end
           modules_by_path[path] = module_names.sort.map do |name|
-            Puppet::Module.new(name, File.join(path, name), self, modules_strict_semver?)
+            Puppet::Module.new(name, File.join(path, name), self)
           end
         end
       else
@@ -434,9 +417,10 @@ class Puppet::Node::Environment
   end
 
   # Loads module translations for the current environment once for
-  # the lifetime of the environment.
+  # the lifetime of the environment. Execute a block in the context
+  # of that translation domain.
   def with_text_domain
-    return if Puppet[:disable_i18n]
+    return yield if Puppet[:disable_i18n]
 
     if @text_domain.nil?
       @text_domain = @name
@@ -448,6 +432,7 @@ class Puppet::Node::Environment
 
     yield
   ensure
+    # Is a noop if disable_i18n is true
     Puppet::GettextConfig.clear_text_domain
   end
 
