@@ -16,7 +16,6 @@ class Puppet::Parser::Compiler
 
   include Puppet::Util
   include Puppet::Util::Errors
-  include Puppet::Util::MethodHelper
   include Puppet::Pops::Evaluator::Runtime3Support
 
   def self.compile(node, code_id = nil)
@@ -27,7 +26,7 @@ class Puppet::Parser::Compiler
       errors.each { |e| Puppet.err(e) } if errors.size > 1
       errmsg = [
         _("Compilation has been halted because: %{error}") % { error: errors.first },
-        _("For more information, see https://docs.puppet.com/puppet/latest/reference/environments.html"),
+        _("For more information, see https://puppet.com/docs/puppet/latest/environments_about.html"),
       ]
       raise(Puppet::Error, errmsg.join(' '))
     end
@@ -397,7 +396,7 @@ class Puppet::Parser::Compiler
   # Return a resource by either its ref or its type and title.
   def_delegator :@catalog, :resource, :findresource
 
-  def initialize(node, options = {})
+  def initialize(node, code_id: nil)
     @node = sanitize_node(node)
     # Array of resources representing all application instances we've found
     @applications = []
@@ -409,7 +408,7 @@ class Puppet::Parser::Compiler
     # in the middle of executing evaluate_applications
     @current_app = nil
     @current_components = nil
-    set_options(options)
+    @code_id = code_id
     initvars
     add_catalog_validators
     # Resolutions of fully qualified variable names
@@ -578,6 +577,7 @@ class Puppet::Parser::Compiler
       end
     end
   end
+  protected :evaluate_generators
 
   # Find and evaluate our main object, if possible.
   def evaluate_main
@@ -642,6 +642,7 @@ class Puppet::Parser::Compiler
 
     add_resource_metaparams
   end
+  protected :finish
 
   def add_resource_metaparams
     unless main = catalog.resource(:class, :main)
@@ -781,8 +782,8 @@ class Puppet::Parser::Compiler
     settings_resource = Puppet::Parser::Resource.new('class', SETTINGS, :scope => @topscope)
 
     @catalog.add_resource(settings_resource)
-
     settings_type.evaluate_code(settings_resource)
+    settings_resource.instance_variable_set(:@evaluated, true) # Prevents settings from being reevaluated
 
     scope = @topscope.class_scope(settings_type)
     scope.merge_settings(environment.name)
