@@ -302,7 +302,8 @@ module Puppet
       end
 
       request.do_request(:fileserver) do |req|
-        connection = Puppet::Network::HttpPool.http_instance(req.server, req.port)
+        ssl_context = Puppet.lookup(:ssl_context)
+        connection = Puppet::Network::HttpPool.connection(req.server, req.port, ssl_context: ssl_context)
         connection.request_get(Puppet::Network::HTTP::API::IndirectedRoutes.request_to_uri(req), add_accept_encoding({"Accept" => BINARY_MIME_TYPES}), &block)
       end
     end
@@ -320,7 +321,6 @@ module Puppet
       end
     end
 
-
     def chunk_file_from_source
       get_from_source do |response|
         case response.code
