@@ -188,7 +188,7 @@ Puppet::Type.newtype(:tidy) do
   end
 
   newparam(:type) do
-    desc "Set the mechanism for determining age. Default: atime."
+    desc "Set the mechanism for determining age."
 
     newvalues(:atime, :mtime, :ctime)
 
@@ -338,7 +338,7 @@ Puppet::Type.newtype(:tidy) do
     begin
       Puppet::FileSystem.lstat(path)
     rescue Errno::ENOENT
-      info _("File does not exist")
+      debug _("File does not exist")
       return nil
     rescue Errno::EACCES
       #TRANSLATORS "stat" is a program name and should not be translated
