@@ -1,5 +1,4 @@
 # Provides feature definitions.
-require 'puppet/util/methodhelper'
 require 'puppet/util/docs'
 require 'puppet/util'
 # This module models provider features and handles checking whether the features
@@ -13,7 +12,6 @@ module Puppet::Util::ProviderFeatures
   # @todo Unclear what is api and what is private in this class
   class ProviderFeature
     include Puppet::Util
-    include Puppet::Util::MethodHelper
     include Puppet::Util::Docs
     attr_accessor :name, :docs, :methods
 
@@ -32,11 +30,10 @@ module Puppet::Util::ProviderFeatures
       end
     end
 
-    def initialize(name, docs, hash)
+    def initialize(name, docs, methods: nil)
       self.name = name.intern
       self.docs = docs
-      hash = symbolize_options(hash)
-      set_options(hash)
+      @methods = methods
     end
 
     private
@@ -81,7 +78,7 @@ module Puppet::Util::ProviderFeatures
     str = ""
     @features ||= {}
     return nil if @features.empty?
-    names = @features.keys.sort_by(&:to_s)
+    names = @features.keys.sort { |a,b| a.to_s <=> b.to_s }
     names.each do |name|
       doc = @features[name].docs.gsub(/\n\s+/, " ")
       str << "- *#{name}*: #{doc}\n"
@@ -130,7 +127,9 @@ module Puppet::Util::ProviderFeatures
       # Create a method that will list all functional features.
       @feature_module.send(:define_method, :features) do
         return false unless defined?(features)
-        features.keys.find_all { |n| feature?(n) }.sort_by(&:to_s)
+        features.keys.find_all { |n| feature?(n) }.sort { |a,b|
+          a.to_s <=> b.to_s
+        }
       end
 
       # Create a method that will determine if a provided list of
