@@ -10,7 +10,7 @@ module Puppet::Util::Windows::Process
   WAIT_INTERVAL = 200
   # https://docs.microsoft.com/en-us/windows/desktop/ProcThread/process-creation-flags
   CREATE_NO_WINDOW = 0x08000000
-  #https://docs.microsoft.com/en-us/windows/desktop/ProcThread/process-security-and-access-rights
+  # https://docs.microsoft.com/en-us/windows/desktop/ProcThread/process-security-and-access-rights
   PROCESS_QUERY_INFORMATION = 0x0400
   # https://docs.microsoft.com/en-us/windows/desktop/FileIO/naming-a-file#maximum-path-length-limitation
   MAX_PATH_LENGTH = 32767
@@ -28,12 +28,10 @@ module Puppet::Util::Windows::Process
     if arguments[:suppress_window]
       create_args[:creation_flags] = CREATE_NO_WINDOW
     end
-    cwd = arguments[:cwd]
-    if cwd
-      Dir.chdir(cwd) { Process.create(create_args) }
-    else
-      Process.create(create_args)
+    if arguments[:cwd]
+      create_args[:cwd] = arguments[:cwd]
     end
+    Process.create(create_args)
   end
   module_function :execute
 
@@ -124,26 +122,26 @@ module Puppet::Util::Windows::Process
   def get_process_image_name_by_pid(pid)
     image_name = ""
 
-     open_process(PROCESS_QUERY_INFORMATION, false, pid) do |phandle|
+    open_process(PROCESS_QUERY_INFORMATION, false, pid) do |phandle|
 
-       FFI::MemoryPointer.new(:dword, 1) do |exe_name_length_ptr|
-        # UTF is 2 bytes/char:
-        max_chars = MAX_PATH_LENGTH + 1
-        exe_name_length_ptr.write_dword(max_chars)
-        FFI::MemoryPointer.new(:wchar, max_chars) do |exe_name_ptr|
+      FFI::MemoryPointer.new(:dword, 1) do |exe_name_length_ptr|
+        # Add 1 for the null terminator, and UTF is 2 bytes/char:
+        max_path_length = (MAX_PATH_LENGTH + 1) * 2
+        exe_name_length_ptr.write_dword(max_path_length)
+        FFI::MemoryPointer.new(max_path_length) do |exe_name_ptr|
           use_win32_path_format = 0
           result = QueryFullProcessImageNameW(phandle, use_win32_path_format, exe_name_ptr, exe_name_length_ptr)
           if result == FFI::WIN32_FALSE
             raise Puppet::Util::Windows::Error.new(
               "QueryFullProcessImageNameW(phandle, #{use_win32_path_format}, " +
-              "exe_name_ptr, #{max_chars}")
+              "exe_name_ptr, #{max_path_length}")
           end
-          image_name = exe_name_ptr.read_wide_string(exe_name_length_ptr.read_dword)
+          image_name = exe_name_ptr.read_wide_string(MAX_PATH_LENGTH + 1)
         end
       end
     end
 
-     image_name
+    image_name
   end
   module_function :get_process_image_name_by_pid
 
